@@ -75,7 +75,7 @@ def insert_one(item: dict, table_name: str, table_schema = None, skip_if_pk_matc
 
     if skip_if_pk_match:
         statement = exists(table)
-        for key in table_schema.primary_keys():
+        for key in table_schema.primary_keys:
             statement = statement.where(table.c[key] == item[key])
 
         statement = select(statement)
