@@ -34,7 +34,7 @@ def upsert_dataframes(target_df: pd.DataFrame, update_df: pd.DataFrame, schema:
 
 
 def apply_delete_columns(target_df: pd.DataFrame, update_df: pd.DataFrame, schema: Schema):
-    delete_columns = schema.delete_columns()
+    delete_columns = schema.delete_columns
     print("delete_columns:", delete_columns)
     delete_values = set([tuple(row) for row in update_df[delete_columns].values])
     print(delete_values)
@@ -62,7 +62,7 @@ def append_missing_values(target_df: pd.DataFrame, update_df: pd.DataFrame, sche
 
 
 def merge_dataframes(target_df: pd.DataFrame, update_df: pd.DataFrame, schema: Schema):
-    if len(schema.primary_keys()) > 0:
+    if len(schema.primary_keys) > 0:
         return upsert_dataframes(target_df, update_df, schema)
     else:
         return apply_delete_columns(target_df, update_df, schema)
