@@ -5,6 +5,7 @@ class DateFormats:
     date_path = "%Y/%m/%d"
     date = "%Y-%m-%d"
     timestamp = "%Y%m%d_%H%M%S"
+    datetime = "%Y-%m-%d %H:%M:%S"
 
 
 def archive_date_today():
@@ -19,6 +20,10 @@ def current_timestamp():
     return datetime.datetime.now().strftime(DateFormats.timestamp)
 
 
+def current_datetime():
+    return datetime.datetime.now().strftime(DateFormats.datetime)
+
+
 def backdated_timestamp(**kwargs):
     return (datetime.datetime.now() - datetime.timedelta(**kwargs)).strftime(DateFormats.timestamp)
 
