@@ -145,7 +145,7 @@ class FileHelper:
 
     # Delete file
     def delete(self, path: str, recursive: bool = False):
-        self.fs.rm(self, self.fspath(path))
+        self.fs.rm(self.fspath(path))
 
     # Get a readable file object
     def get_readable(self, path: str):
